#=========================================================================
# R-file evaluating the duration of bilateral trade relationships      
# author: Wolfgang Hess
# note:   due to the large data set used this code may not run on a
#         conventional PC without special measures to allocate memory to R
# ========================================================================




library(foreign)
library(gamlss.mx)
set.seed(4537269)




######################################################################
# Hoehle modified function for gamlssNP. This should be somewhat more
# memory conserving.
# New option:
#  reduceMemory - Boolean. If TRUE then entries mu,x and mu.qr are not
#                 saved.
######################################################################

gamlssNP <- function (formula, random = ~1, family = NO(), data = NULL, K = 4, 
    mixture = c("np", "gq"), tol = 0.5, weights, pluginz, control = NP.control(...), 
    g.control = gamlss.control(trace = FALSE), reduceMemory=FALSE,...) 
{
    expand.vc <- function(x, ni) {
        if (length(ni) == 1) {
            if (ni < 1) 
                stop("ni should be greater than 1")
            xx <- x
            if (ni == 1) 
                return(xx)
            for (i in 2:ni) xx <- rbind(x, xx)
            xx
        }
        else {
            n <- dim(x)[[1]]
            c <- dim(x)[[2]]
            xx <- NULL
            for (i in seq(1, n)) {
                xx <- rbind(xx, matrix(rep(x[i, ], ni[i]), ncol = c, 
                  byrow = TRUE))
            }
            xx
        }
    }
    weightslogl.calc.w <- function(p, fjk, weights) {
        logpf <- t(apply(fjk, 1, "+", log(p)))
        pf <- exp(logpf)
        Spf <- as.vector(apply(pf, 1, sum))
        w <- pf/Spf
        ML.dev <- -2 * sum(weights * log(Spf))
        list(w = w, ML.dev = ML.dev)
    }
    get.log.likelihood.firstTime <- function(obj, mu, ...) {
        if (!is.gamlss(obj)) 
            stop(paste("This is not an gamlss object", "\n", 
                ""))
        fname <- obj$family[[1]]
        DistPar <- obj$parameters
        nopar <- length(DistPar)
        dfun <- paste("d", fname, sep = "")
        if (fname %in% gamlss.bi.list) {
            yy <- rep(obj$y, K)
            bd <- rep(obj$bd, K)
        }
        else {
            yy <- rep(obj$y, K)
        }
        if (("sigma" %in% obj$parameters)) 
            sigma <- rep(fitted(obj, "sigma"), K)
        if (("nu" %in% obj$parameters)) 
            nu <- rep(fitted(obj, "nu"), K)
        if (("tau" %in% obj$parameters)) 
            tau <- rep(fitted(obj, "tau"), K)
        switch(nopar, {
            lik <- if (fname %in% gamlss.bi.list) 
                eval(call(dfun, x = yy, bd = bd, mu = mu, log = TRUE))
            else eval(call(dfun, x = yy, mu = mu, log = TRUE))
        }, {
            lik <- if (fname %in% gamlss.bi.list) 
                eval(call(dfun, x = yy, bd = bd, mu = mu, sigma = sigma, 
                  log = TRUE))
            else eval(call(dfun, x = yy, mu = mu, sigma = sigma, 
                log = TRUE))
        }, {
            lik <- eval(call(dfun, x = yy, mu = mu, sigma = sigma, 
                nu = nu, log = TRUE))
        }, {
            lik <- eval(call(dfun, x = yy, mu = mu, sigma = sigma, 
                nu = nu, tau = tau, log = TRUE))
        })
        lik
    }
    get.log.likelihood <- function(obj, ...) {
        gamlss.bi.list <- c("BI", "Binomial", "BB", "Beta Binomial")
        if (!is.gamlss(obj)) 
            stop(paste("This is not an gamlss object", "\n", 
                ""))
        fname <- obj$family[[1]]
        DistPar <- obj$parameters
        nopar <- length(DistPar)
        dfun <- paste("d", fname, sep = "")
        switch(nopar, {
            lik <- if (fname %in% gamlss.bi.list) 
                eval(call(dfun, x = obj$y, bd = obj$bd, mu = fitted(obj, 
                  "mu"), log = TRUE))
            else eval(call(dfun, x = obj$y, mu = fitted(obj, 
                "mu"), log = TRUE))
        }, {
            lik <- if (fname %in% gamlss.bi.list) 
                eval(call(dfun, x = obj$y, bd = obj$bd, mu = fitted(obj, 
                  "mu"), sigma = fitted(obj, "sigma"), log = TRUE))
            else eval(call(dfun, x = obj$y, mu = fitted(obj, 
                "mu"), sigma = fitted(obj, "sigma"), log = TRUE))
        }, {
            lik <- eval(call(dfun, x = obj$y, mu = fitted(obj, 
                "mu"), sigma = fitted(obj, "sigma"), nu = fitted(obj, 
                "nu"), log = TRUE))
        }, {
            lik <- eval(call(dfun, x = obj$y, mu = fitted(obj, 
                "mu"), sigma = fitted(obj, "sigma"), nu = fitted(obj, 
                "nu"), tau = fitted(obj, "tau"), log = TRUE))
        })
        lik
    }
    get.the.p.function <- function(object, ...) {
        gamlss.bi.list <- c("BI", "Binomial", "BB", "Beta Binomial")
        if (!is.gamlss(object)) 
            stop(paste("This is not an gamlss object", "\n", 
                ""))
        fname <- object$family[[1]]
        DistPar <- object$parameters
        nopar <- length(DistPar)
        dfun <- paste("p", fname, sep = "")
        switch(nopar, {
            pfun <- if (fname %in% gamlss.bi.list) 
                eval(call(dfun, q = object$y, bd = object$bd, 
                  mu = fitted(object, "mu")))
            else eval(call(dfun, q = object$y, mu = fitted(object, 
                "mu")))
        }, {
            pfun <- if (fname %in% gamlss.bi.list) 
                eval(call(dfun, q = object$y, bd = object$bd, 
                  mu = fitted(object, "mu"), sigma = fitted(object, 
                    "sigma")))
            else eval(call(dfun, q = object$y, mu = fitted(object, 
                "mu"), sigma = fitted(object, "sigma")))
        }, {
            pfun <- eval(call(dfun, q = object$y, mu = fitted(object, 
                "mu"), sigma = fitted(object, "sigma"), nu = fitted(object, 
                "nu")))
        }, {
            pfun <- eval(call(dfun, q = object$y, mu = fitted(object, 
                "mu"), sigma = fitted(object, "sigma"), nu = fitted(object, 
                "nu"), tau = fitted(object, "tau")))
        })
        pfun
    }
    mixture <- match.arg(mixture)
    EMn.cyc <- control$EMn.cyc
    EMcc <- control$EMcc
    verbose <- control$trace
    plot.opt <- control$plot.opt
    damp <- control$damp
    gamlss.bi.list <- c("BI", "Binomial", "BB", "Beta Binomial")
    call <- match.call()
    if (missing(data)) 
        stop("the data argument is needed")
    if (!missing(data) & any(is.na(data))) 
        stop("The data contains NA's, use data = na.omit(mydata)")
    family <- as.gamlss.family(family)
    Y <- model.extract(model.frame(formula, data = data), "response")
    N <- if (is.null(dim(Y))) 
        length(Y)
    else dim(Y)[1]
    pweights <- if (missing(weights)) 
        rep(1, N)
    else weights
    data <- data.frame(data, pweights)
    fitout <- gamlss(formula, family = family, weights = pweights, 
        data = data, control = g.control)
    l0 <- length(coef(fitout, "mu"))
    if (K == 1) {
        return(fitout)
    }
    datak <- expand.vc(data, K)
    kindex <- rep(1:K, rep(N, K))
    tmp <- gqz(K, minweight = 1e-14)
    z0 <- -tmp$l
    z <- rep(-tmp$l, rep(N, K))
    p <- tmp$w
    rform <- random
    mform <- strsplit(as.character(random)[2], "\\|")[[1]]
    mform <- gsub(" ", "", mform)
    if (length(mform) == 2) {
        mform1 <- mform[1]
        mform2 <- mform[2]
        group <- factor(levels(as.factor(datak[, mform2])))
        nr <- nlevels(group)
        ijindex <- rep(1:N, K)
        groupij <- data[, mform2]
        groupijk <- rep(groupij, K)
    }
    else {
        mform1 <- mform
    }
    if (mixture == "np") {
        datak$MASS <- gl(K, N)
        if (mform1 == "1") 
            random <- formula(~MASS)
        else {
            random <- formula(paste("~ MASS + ", paste(mform1, 
                "MASS", sep = ":", collapse = "+"), sep = ""))
        }
    }
    else {
        datak$z <- z
        if (mform1 == "1") {
            random <- formula(~z)
        }
        else {
            random <- formula(paste("~ z + ", paste(mform1, "z", 
                sep = ":", collapse = "+"), sep = ""))
        }
    }
    if (missing(pluginz)) {
        sz <- if ("sigma" %in% fitout$parameters) 
            tol * fitted(fitout, "sigma") * z
        else tol * z
    }
    else {
        sz <- if ("sigma" %in% fitout$parameters) 
            rep(pluginz - fitout$mu.coef[[1]], rep(N, K))
    }
    Eta <- fitout$mu.lp + sz
    if (mixture == "np") {
        tol <- max(min(tol, 1), 1 - damp)
        if (length(fitout$coef) == 1) {
            followmass <- matrix(Eta[(1:K) * N], 1, K)
        }
        else {
            followmass <- matrix(fitout$mu.coef[1] + sz[(1:K) * 
                N], 1, K)
        }
    }
    else {
        followmass <- NULL
        tol <- 1
    }
    Mu <- family$mu.linkinv(Eta)
    logf <- get.log.likelihood.firstTime(fitout, Mu)
    logf <- ifelse(logf > -700, logf, -700)
    if (length(mform) == 2) {
        groupk <- interaction(groupijk, factor(kindex))
        logmik <- matrix(tapply(logf, groupk, sum), nrow = nr, 
            ncol = K)
        #hoehle 09.04.2010: Problem if there are no instances of a specific
        #groupk factor level -> NA. But we don't want NAs
        logmik[is.na(logmik)] <- 0
        tmp <- weightslogl.calc.w(p, logmik, pweights[1:nr])
        ww <- as.vector(tmp$w[match(groupij, group), ])
        ww <- ifelse(ww < 1e-20, 0, ww)
    }
    else {
        tmp <- weightslogl.calc.w(p, matrix(logf, ncol = K), 
            rep(pweights, K))
        ww <- as.vector(tmp$w)
        ww <- ifelse(ww < 1e-20, 0, ww)
    }
    datak <- data.frame(datak, ww)
#hoehle: 27.11.2009 This is problematic
#    ex <- parse(text = paste(deparse(formula[[3]]), deparse(random[[2]]), 
#        sep = "+"))
    ex <- parse(text = paste(paste(deparse(formula[[3]]),collapse=""), paste(deparse(random[[2]]),collapse=""),sep="+"))
    formula[[3]] <- ex[[1]]
    ML.dev <- ML.dev0 <- deviance(fitout)
    cat("ML.dev0 = \n")
    print(ML.dev)
    
    iter <- ml <- 1
    converged <- FALSE
    while (iter <= EMn.cyc && (!converged || (iter <= 9 && mixture == 
        "np"))) {
        if (verbose) {
            cat(iter, "..")
        }
        fitout <- if (iter == 1) {
            gamlss(formula, family = family, weights = ww * pweights, 
                data = datak, control = g.control, ...)
        }
        else {
            gamlss(formula, family = family, weights = ww * pweights, 
                data = datak, control = g.control, start.from = fitout, 
                ...)
        }
        if (mixture == "np") {
            attcoef <- attr(coef(fitout), "names")
            if (mform1 == "1") {
                masspoint <- c(coef(fitout)[grep("(Intercept)", 
                  attcoef)], coef(fitout)[grep("(Intercept)", 
                  attcoef)] + coef(fitout)[grep("MASS", attcoef)])
            }
            else {
                sdif <- setdiff(grep("MASS", attcoef), grep(mform1, 
                  attcoef))
                masspoint <- c(coef(fitout)[grep("(Intercept)", 
                  attcoef)], coef(fitout)[grep("(Intercept)", 
                  attcoef)] + coef(fitout)[sdif])
            }
            followmass <- rbind(followmass, masspoint)
        }
        logf <- get.log.likelihood(fitout)
        logf <- ifelse(logf > -740, logf, -740)
        logf <- matrix(logf, ncol = K)
        if (mixture == "np") 
            p <- as.vector(tapply(ww, kindex, mean))
        if (length(mform) == 2) {
            logmik <- matrix(tapply(logf, groupk, sum), nrow = nr, 
                ncol = K)
            #hoehle 09.04.2010: Problem if there are no instances of a specific
            #groupk factor level -> NA. But we don't want NAs
            logmik[is.na(logmik)] <- 0
            tmp <- weightslogl.calc.w(p, logmik, pweights[1:nr])
            ww <- as.vector(tmp$w[match(groupij, group), ])
            ww <- ifelse(ww < 1e-20, 0, ww)
        }
        else {
            tmp <- weightslogl.calc.w(p, matrix(logf, ncol = K), 
                pweights[1:N])
            ww <- as.vector(tmp$w)
            ww <- ifelse(ww < 1e-20, 0, ww)
        }
        datak$ww <- ww
        ML.dev[iter + 1] <- tmp$ML.dev
        ##Searching for the bug.
        cat("ML.dev[iter + 1]:\n")
        print(ML.dev[iter + 1])
        if (ML.dev[iter + 1] > ML.dev0) {
            ml <- ml + 1
        }
        converged <- abs(ML.dev[iter + 1] - ML.dev[iter]) < EMcc
        iter <- iter + 1
    }
    if (verbose) {
        cat("\n")
        if (converged) {
            cat("EM algorithm met convergence criteria at iteration  ", 
                iter - 1, "\n")
        }
        else {
            cat("EM algorithm failed to meet convergence criteria at iteration # ", 
                iter - 1, "\n")
        }
    }
    mass.points <- masses <- NULL
    np <- length(fitout$mu.coef)
    ebp <- apply(ww * matrix(fitout$mu.lp, N, K, byrow = FALSE), 
        1, sum)
    if (plot.opt == 3 && mixture == "np") {
        op <- par(mfrow = c(2, 1), cex = 0.5, cex.axis = 1.5, 
            cex.lab = 1.5)
        on.exit(par(op))
    }
    if (plot.opt == 1 || plot.opt == 3) {
        if ((family$type == "continuous") && damp && mixture == 
            "np" && iter >= max(8, ml + 1)) {
            ML.dev[2:max(7, ml)] <- ML.dev0 + 1:max(6, ml - 1)/max(7, 
                ml) * (ML.dev[max(8, ml + 1)] - ML.dev0)
        }
        plot(0:(iter - 1), ML.dev, col = 1, type = "l", xlab = "EM iterations", 
            ylab = "-2logL")
        if (verbose) {
            cat("Global deviance trend plotted.\n")
        }
    }
    if (mixture == "np") {
        ylim <- c(min(followmass[, ]), max(followmass[, ]))
        if (plot.opt == 2 || plot.opt == 3) {
            plot(0:(iter - 1), followmass[, 1], col = 1, type = "l", 
                ylim = ylim, ylab = "mass points", xlab = "EM iterations")
            for (i in 1:K) {
                lines(0:(iter - 1), followmass[, i], col = i)
            }
            if (verbose) {
                cat("EM Trajectories plotted.\n")
            }
        }
    }
    prob <- apply(matrix(ww, ncol = K), 2, mean)
    WF <- matrix(get.the.p.function(fitout), ncol = K, nrow = N)
    for (i in 1:K) WF[, i] <- prob[i] * WF[, i]
    res <- qnorm(rowSums(WF))
    fitout$df.fit <- if (mixture == "np") 
        fitout$df.fit + K - 1
    else fitout$df.fit
    fitout$df.residual <- N - fitout$df.fit
    fitout$G.deviance <- ML.dev[iter]
    fitout$call <- call
    fitout$formula <- formula
    fitout$random <- rform
    fitout$post.prob <- list(matrix(ww, nrow = N, byrow = FALSE))
    fitout$data <- data
    fitout$ebp <- ebp
    fitout$EMiter <- iter - 1
    fitout$pweights <- pweights
    fitout$EMconverged <- converged
    fitout$aic <- fitout$G.deviance + 2 * fitout$df.fit
    fitout$sbc <- fitout$G.deviance + log(N) * fitout$df.fit
    fitout$allresiduals <- fitout$residuals
    fitout$residuals <- res
    fitout$N <- N
    fitout$K <- K
    fitout$type <- "Mixture"
    if (mixture == "np") {
        if (mform1 == "1") {
            fitout$mass.points <- masspoint
        }
        else {
            lf <- length(mform1)
            MASSPOINT <- matrix(0, ncol = lf + 1, nrow = K)
            MASSPOINT[, 1] <- masspoint
            for (i in 1:lf) {
                mm <- grep(mform1[i], attcoef)
                MASSPOINT[, i + 1] <- c(coef(fitout)[mm[1]], 
                  coef(fitout)[mm[1]] + coef(fitout)[mm[2:K]])
            }
            fitout$mass.points <- MASSPOINT
        }
        masses <- prob
        names(masses) <- paste("MASS", 1:K, sep = "")
        fitout$prob <- masses
        fitout$family <- paste(fitout$family, "Mixture with NP")
    }
    else {
        fitout$mass.points <- fitout$coef[1] + fitout$coef[np] * 
            z0
        fitout$family <- paste(fitout$family[[1]], "Mixture with NO")
        fitout$prob <- list(gqz(K)$w)
    }
    class(fitout) <- list("gamlssNP", "gamlss")

    #hoehle: 15.01.2010. Small hack to reduce memory of the object returned
    sink(file="gamlssNP-summary.txt")
    summary(fitout)
    sink()
    
    if (reduceMemory) {
        largeNames <- c(#Large
                        "mu.x", "mu.qr",
                        #Medium
                        "y","weights","mu.fv","mu.lp","mu.wv",
                        "mu.wt","sigma.fv","sigma.lp","sigma.wv","sigma.wt", "sigma.qr",
                        "sigma.x","nu.fv","nu.lp","nu.wv",
                        "nu.wt","nu.x","tau.fv","tau.lp",  "nu.qr",
                        "tau.wv","tau.wt","tau.x","data","allresiduals","tau.qr",
                        #Small
                        "post.prob"
                        )
        for (n in largeNames) { fitout[[n]] <- NULL }

        attr(fitout$mu.terms,".Environment") <- NULL
        attr(fitout$mu.formula,".Environment") <- NULL
        attr(fitout$sigma.terms,".Environment") <- NULL
        attr(fitout$sigma.formula,".Environment") <- NULL
        attr(fitout$nu.terms,".Environment") <- NULL
        attr(fitout$nu.formula,".Environment") <- NULL
        attr(fitout$tau.terms,".Environment") <- NULL
        attr(fitout$tau.formula,".Environment") <- NULL
        attr(fitout$formula,".Environment") <- NULL
        attr(fitout$random,".Environment") <- NULL

#        fitout$call <- NULL
        fitout$ebb <- NULL
        fitout$pweights <- NULL
        fitout$residuals <- NULL
        fitout$noObs <- NULL
        fitout$N <- NULL
        #fitout$G.deviance <- NULL
        fitout$P.deviance <- NULL
        fitout$aic <- NULL
        fitout$sbc <- NULL
    }
    
    fitout
}



#----------------------------------------------------------------------------------------
residuals.gamlssNP <- function(object,...)
{
object$residuals
}
#----------------------------------------------------------------------------------------
#par(mfrow=c(2,2), mar=par("mar")+c(0,1,0,0), col.axis="blue4", col="blue4", col.main="blue4",col.lab="blue4",pch="+",cex=.45, cex.lab=1.2, cex.axis=1, cex.main=1.2  )
#---------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------
#
#----------------------------------------------------------------------------------------
# this is  Nick Sofroniou function from the package 
# npmlreg of  Jochen Einbeck, Ross Darnell and John Hinde (2006).
gqz <- function (numnodes = 20, minweight = 1e-06) 
{
    out <- gauss.quad(numnodes, "hermite")
    h <- rbind(out$nodes * sqrt(2), out$weights/sum(out$weights))
    ord <- order(h[1, ], decreasing = TRUE)
    h <- h[, ord]
    h <- cbind(h[1, ], h[2, ])
    h <- subset(as.data.frame(h), (h[, 2] >= minweight))
    names(h) <- c("location", "weight")
    h
}
#----------------------------------------------------------------------------------------
# this  Gordon Smyth function from package 
# package:statmod 
# see there for documantation
gauss.quad <- function (n, kind = "legendre", alpha = 0, beta = 0) 
{
    n <- as.integer(n)
    if (n < 0) 
        stop("need non-negative number of nodes")
    if (n == 0) 
        return(list(nodes = numeric(0), weights = numeric(0)))
    kind <- match.arg(kind, c("legendre", "chebyshev1", "chebyshev2", 
        "hermite", "jacobi", "laguerre"))
    i <- 1:n
    i1 <- i[-n]
    switch(kind, legendre = {
        muzero <- 2
        a <- rep(0, n)
        b <- i1/sqrt(4 * i1^2 - 1)
    }, chebyshev1 = {
        muzero <- pi
        a <- rep(0, n)
        b <- rep(0.5, n - 1)
        b[1] <- sqrt(0.5)
    }, chebyshev2 = {
        muzero <- pi/2
        a <- rep(0, n)
        b <- rep(0.5, n - 1)
    }, hermite = {
        muzero <- sqrt(pi)
        a <- rep(0, n)
        b <- sqrt(i1/2)
    }, jacobi = {
        ab <- alpha + beta
        muzero <- 2^(ab + 1) * gamma(alpha + 1) * gamma(beta + 
            1)/gamma(ab + 2)
        a <- i
        a[1] <- (beta - alpha)/(ab + 2)
        i2 <- 2:n
        abi <- ab + 2 * i2
        a[i2] <- (beta^2 - alpha^2)/(abi - 2)/abi
        b <- i1
        b[1] <- sqrt(4 * (alpha + 1) * (beta + 1)/(ab + 2)^2/(ab + 
            3))
        i2 <- i1[-1]
        abi <- ab + 2 * i2
        b[i2] <- sqrt(4 * i2 * (i2 + alpha) * (i2 + beta) * (i2 + 
            ab)/(abi^2 - 1)/abi^2)
    }, laguerre = {
        a <- 2 * i - 1 + alpha
        b <- sqrt(i1 * (i1 + alpha))
        muzero <- gamma(alpha + 1)
    })
    A <- rep(0, n * n)
    A[(n + 1) * (i - 1) + 1] <- a
    A[(n + 1) * (i1 - 1) + 2] <- b
    A[(n + 1) * i1] <- b
    dim(A) <- c(n, n)
    vd <- eigen(A, symmetric = TRUE)
    w <- rev(as.vector(vd$vectors[1, ]))
    w <- muzero * w^2
    x <- rev(vd$values)
    list(nodes = x, weights = w)
}
#----------------------------------------------------------------------------------------


dat<-read.dta("pareto_data.dta")
attach(dat)

burr <- function(xi=1) 
{ 
  linkfun <- function(mu) log(((1-mu)^(-xi)-1)/xi) 
  linkinv <- function(eta) 1-(1+xi*exp(eta))^(-1/xi) 
  mu.eta <- function(eta) exp(eta)*(1+xi*exp(eta))^(-1/xi-1) 
  valideta <- function(eta) TRUE 
  link <- paste("burr(", xi, ")", sep="") 
  structure(list(linkfun = linkfun, linkinv = linkinv, 
                 mu.eta = mu.eta, valideta = valideta, name = link), 
            class = "link-gamlss") 
}


modelp <- gamlssNP(y ~ t2+t3+t4+t5+t6+t7+t8+t9+t10+t11+t12+t13+t14+t15_16
                   +transport+gdp+tariff+pctrer_relative+cov_uv+spelldum
                   +agriculture+reference_priced+homogeneous, 
                   random=~1|id, family = BI(probit), 
                   data=dat, K=3, mixture="gq", tol=0.5, control = NP.control(EMcc=0.4, trace=FALSE), 
                   g.control = gamlss.control(trace=FALSE), reduceMemory=FALSE)

modelp$EMconverged
modelp$converged
summary(modelp)
coefmodelp<-coef(modelp)
devmodelp<-modelp$G.deviance
ebpmodelp<-modelp$ebp
save(coefmodelp, devmodelp, ebpmodelp, file="trade_xips4.RData")
rm(modelp)

model44 <- gamlssNP(y ~ t2+t3+t4+t5+t6+t7+t8+t9+t10+t11+t12+t13+t14+t15_16
                    +transport+gdp+tariff+pctrer_relative+cov_uv+spelldum
                    +agriculture+reference_priced+homogeneous, 
                    random=~1|id, family = BI(burr(xi=4.4)), 
                    data=dat, K=3, mixture="gq", tol=0.5, control = NP.control(EMcc=0.4, trace=FALSE), 
                    g.control = gamlss.control(trace=FALSE), reduceMemory=FALSE)

model44$EMconverged
model44$converged
summary(model44)
coefmodel44<-coef(model44)
devmodel44<-model44$G.deviance
ebpmodel44<-model44$ebp
save(coefmodel44, devmodel44, ebpmodel44, file="trade_xi44s4.RData")
rm(model44)

model00 <- gamlssNP(y ~ t2+t3+t4+t5+t6+t7+t8+t9+t10+t11+t12+t13+t14+t15_16
                    +transport+gdp+tariff+pctrer_relative+cov_uv+spelldum
                    +agriculture+reference_priced+homogeneous, 
                    random=~1|id, family = BI(cloglog), 
                    data=dat, K=3, mixture="gq", tol=0.5, control = NP.control(EMcc=0.4, trace=FALSE), 
                    g.control = gamlss.control(trace=FALSE), reduceMemory=FALSE)

model00$EMconverged
model00$converged
summary(model00)
coefmodel00<-coef(model00)
devmodel00<-model00$G.deviance
ebpmodel00<-model00$ebp
save(coefmodel00, devmodel00, ebpmodel00, file="trade_xi00s4.RData")
rm(model00)

model10 <- gamlssNP(y ~ t2+t3+t4+t5+t6+t7+t8+t9+t10+t11+t12+t13+t14+t15_16
                    +transport+gdp+tariff+pctrer_relative+cov_uv+spelldum
                    +agriculture+reference_priced+homogeneous, 
                    random=~1|id, family = BI(logit), 
                    data=dat, K=3, mixture="gq", tol=0.5, control = NP.control(EMcc=0.4, trace=FALSE), 
                    g.control = gamlss.control(trace=FALSE), reduceMemory=FALSE)

model10$EMconverged
model10$converged
summary(model10)
coefmodel10<-coef(model10)
devmodel10<-model10$G.deviance
ebpmodel10<-model10$ebp
save(coefmodel10, devmodel10, ebpmodel10, file="trade_xi10s4.RData")
rm(model10)